@@ -1,21 +1,13 @@
 from loguru import logger
 import functools
 import time
-import builtins
 
 
 
-def get_errors():
-    errors = []
-    for i in dir(builtins):
-        if 'Error' in i:
-            errors.append(getattr(builtins, i))
-    return errors
-
 
 #logger.add("app.log", rotation="500 MB", compression="zip")
 
-def elog(func):
+def logexc(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         logger.info(f"Starting function {func.__name__}")
@@ -32,7 +24,7 @@ def elog(func):
 
     return wrapper
 
-def timeit(func):
+def logtime(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         start_time = time.time()
